@@ -34,7 +34,8 @@ def mock_action_view(assigns = {})
   controller = ActionView::TestCase::TestController.new
   ActionView::Base.send :include, ActionView::Helpers
   ActionView::Base.send :include, AdditionalHelpers
-  ActionView::Base.new(ActionController::Base.view_paths, assigns, controller)
+  context = ActionView::LookupContext.new(ActionController::Base.view_paths)
+  ActionView::Base.new(context, assigns, controller)
 end
 
 RSpec.configure do |config|
